@@ -16,6 +16,7 @@ from dxi._lib import run_job
 from dxi._lib.dxi_constants import BookmarkOps
 from dxi._lib.dxi_constants import DataLayoutType
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -27,8 +28,8 @@ class BookmarkConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     ENGINE_ID = "default"
     PARALLEL = 5
     TYPE = None
