@@ -1,7 +1,7 @@
 #
 # Copyright (c) 2021 by Delphix. All rights reserved.
 #
-
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.database._internal_lib._dxi_db import DXIDb
 from dxi.database._internal_lib._dxi_ingest import DXIDsource
 from dxi.database._internal_lib._dxi_provision import DXIVdb
@@ -14,8 +14,8 @@ class DXIDatabaseConstants(object):
 
     SINGLE_THREAD = False
     POLL = 10
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     ENGINE_ID = "default"
     PARALLEL = 5
     ACTION = None
